@@ -4,12 +4,17 @@ Cares about the correct creation and handling of need layout.
 Based on https://github.com/useblocks/sphinxcontrib-needs/issues/102
 """
 import re
+import os
+import requests
+
 from docutils import nodes
 from docutils.frontend import OptionParser
 from docutils.parsers.rst import languages, Parser
 from docutils.parsers.rst.states import Inliner, Struct
 from docutils.utils import new_document
 
+from urllib.parse import urlparse
+
 from sphinxcontrib.needs.utils import INTERNALS
 
 
@@ -460,7 +465,7 @@ class LayoutHandler:
         Returns the specific meta data of a need inside docutils nodes.
         Usage::
 
-            <<meta('status', prefix:'**status**', show_empty=True)>>
+            <<meta('status', prefix='**status**', show_empty=True)>>
 
         :param name: name of the need item
         :param prefix: string as rst-code, will be added infront of the value output
@@ -654,7 +659,8 @@ class LayoutHandler:
 
         return data_container
 
-    def image(self, url, height=None, width=None, align=None, no_link=False):
+    def image(self, url, height=None, width=None, align=None, no_link=False, prefix="",
+              is_external=False):
         """
 
         See https://docutils.sourceforge.io/docs/ref/rst/directives.html#images
@@ -670,13 +676,24 @@ class LayoutHandler:
 
             '<<image("_images/useblocks_logo.png", height="50px", align="center")>>',
             '<<image("icon:bell", height="20px", align="center")>>'
+            '<<image("field:url", height="60px", align="center")>>'  # Get url from need['url']
 
+        :param no_link:
         :param url:
         :param height:
         :param width:
         :param align:
+        :param prefix: Prefix string infront of the image
+        :param is_external: If ``True`` url references an external image, which needs to be downloaded
         :return:
         """
+        data_container = nodes.inline()
+        if prefix is not None:
+            prefix_node = self._parse(prefix)
+            label_node = nodes.inline(classes=['needs_label'])
+            label_node += prefix_node
+            data_container.append(label_node)
+
         # from sphinx.addnodes import
         options = {}
         if height is not None:
@@ -697,15 +714,12 @@ class LayoutHandler:
                 builder_extension = 'svg'
 
             # url = '_static/sphinx-needs/images/{}.{}'.format(url.split(':')[1], builder_extension)
-            import os
             needs_location = os.path.dirname(__file__)
             url = os.path.join(needs_location,
                                'images',
                                'feather_{}'.format(builder_extension),
                                '{}.{}'.format(url.split(':')[1], builder_extension))
 
-            # url = '../sphinxcontrib/needs/images/feather_{}/{}.{}'.format(builder_extension, url.split(':')[1], builder_extension)
-
             # if any(x in self.app.builder.name.upper() for x in ['PDF', 'LATEX']) is False:
             #     # This is not needed for Latex. as latex puts the complete content in a single text file on root level
             #     # The url needs to be relative to the current document where the need is defined
@@ -724,8 +738,29 @@ class LayoutHandler:
                 return []
 
             url = value
-            subfolder_amount = self.need['docname'].count('/')
-            url = '../' * subfolder_amount + url
+
+            if not is_external and not os.path.isabs(url):
+                subfolder_amount = self.need['docname'].count('/')
+                url = '../' * subfolder_amount + url
+
+        if is_external:
+            url_parsed = urlparse(url)
+            filename = os.path.basename(url_parsed.path) + '.png'
+            path = os.path.join(self.app.srcdir, "images")
+            file_path = os.path.join(path, filename)
+
+            # Download only, if file not downloaded yet
+            if not os.path.exists(file_path):
+                try:
+                    os.mkdir(path)
+                except FileExistsError:
+                    pass
+                response = requests.get(url)
+                if response.status_code == 200:
+                    with open(file_path, 'wb') as f:
+                        f.write(response.content)
+
+            url = file_path
 
         image_node = nodes.image(url, classes=['needs_image'], **options)
         image_node['candidates'] = {'*': url}
@@ -749,9 +784,11 @@ class LayoutHandler:
             ref_node.append(image_node)
             return ref_node
 
-        return image_node
+        data_container.append(image_node)
+        return data_container
 
-    def link(self, url, text=None, image_url=None, image_height=None, image_width=None):
+    def link(self, url, text=None, image_url=None, image_height=None, image_width=None,
+             prefix="", is_dynamic=False):
         """
         Shows a link.
         Link can be a text, an image or both
@@ -761,19 +798,40 @@ class LayoutHandler:
         :param image_url:
         :param image_height:
         :param image_width:
+        :param prefix: Additional string infront of the string
+        :param is_dynamic: if ``True``, ``url`` is not static and gets read from need
         :return:
+
+        Examples::
+
+            <<link('http://sphinx-docs.org', 'Sphinx')>>
+            <<link('url', 'Link', is_dynamic=True)>>  # Reads url from need[url]
         """
+        data_container = nodes.inline()
+        if prefix is not None:
+            prefix_node = self._parse(prefix)
+            label_node = nodes.inline(classes=['needs_label'])
+            label_node += prefix_node
+            data_container.append(label_node)
 
         if text is None:  # May be needed if only image shall be shown
             text = ''
 
+        if is_dynamic:
+            try:
+                url = self.need[url]
+            except KeyError:
+                url = ''
+
         link_node = nodes.reference(text, text, refuri=url)
 
         if image_url is not None:
             image_node = self.image(image_url, image_height, image_width)
             link_node.append(image_node)
 
-        return link_node
+        data_container.append(link_node)
+
+        return data_container
 
     def collapse_button(self, target='meta', collapsed='Show', visible='Close', initial=False):
         """
