@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import os
-import random
-import string
-
 import sphinx
 from sphinx.errors import SphinxError
 from docutils import nodes
@@ -20,11 +16,12 @@ from sphinxcontrib.needs.directives.needpie import Needpie, NeedpieDirective, pr
 from sphinxcontrib.needs.directives.needsequence import Needsequence, NeedsequenceDirective, process_needsequence
 from sphinxcontrib.needs.directives.needgantt import Needgantt, NeedganttDirective, process_needgantt
 from sphinxcontrib.needs.directives.needextract import Needextract, NeedextractDirective, process_needextract
+from sphinxcontrib.needs.directives.needservice import Needservice, NeedserviceDirective
 
 from sphinxcontrib.needs.builder import NeedsBuilder
 from sphinxcontrib.needs.directives.needfilter import Needfilter, NeedfilterDirective, process_needfilters
 from sphinxcontrib.needs.environment import install_styles_static_files, install_datatables_static_files, \
-    install_collapse_static_files, install_feather_icons
+    install_collapse_static_files
 from sphinxcontrib.needs.roles.need_incoming import Need_incoming, process_need_incoming
 from sphinxcontrib.needs.roles.need_outgoing import Need_outgoing, process_need_outgoing
 from sphinxcontrib.needs.roles.need_ref import Need_ref, process_need_ref
@@ -35,6 +32,9 @@ from sphinxcontrib.needs.warnings import process_warnings
 from sphinxcontrib.needs.utils import INTERNALS, NEEDS_FUNCTIONS
 from sphinxcontrib.needs.defaults import DEFAULT_DIAGRAM_TEMPLATE, LAYOUTS, NEEDFLOW_CONFIG_DEFAULTS
 
+from sphinxcontrib.needs.services.manager import ServiceManager
+from sphinxcontrib.needs.services.github import GithubService
+
 sphinx_version = sphinx.__version__
 if parse_version(sphinx_version) >= parse_version("1.6"):
     from sphinx.util import logging
@@ -43,7 +43,7 @@ else:
 
     logging.basicConfig()  # Only need to do this once
 
-VERSION = '0.5.6'
+VERSION = '0.6.0'
 
 NEEDS_FUNCTIONS_CONF = []
 
@@ -58,6 +58,7 @@ class TagsDummy:
 
 def setup(app):
     log = logging.getLogger(__name__)
+    log.debug("Starting setup of sphinx-Needs")
     app.add_builder(NeedsBuilder)
     app.add_config_value('needs_types',
                          [dict(directive="req", title="Requirement", prefix="R_", color="#BFD8D2", style="node"),
@@ -142,6 +143,9 @@ def setup(app):
 
     app.add_config_value('needs_template_folder', 'needs_templates/', 'html')
 
+    app.add_config_value('needs_services', {}, 'html')
+    app.add_config_value('needs_service_all_data', False, 'html')
+
     # Define nodes
     app.add_node(Need, html=(html_visit, html_depart), latex=(latex_visit, latex_depart))
     app.add_node(Needfilter, )
@@ -153,6 +157,7 @@ def setup(app):
     app.add_node(Needsequence)
     app.add_node(Needgantt)
     app.add_node(Needextract)
+    app.add_node(Needservice)
     app.add_node(NeedPart, html=(visitor_dummy, visitor_dummy), latex=(visitor_dummy, visitor_dummy))
 
     ########################################################################
@@ -169,6 +174,7 @@ def setup(app):
     app.add_directive('needgantt', NeedganttDirective)
     app.add_directive('needimport', NeedimportDirective)
     app.add_directive('needextract', NeedextractDirective)
+    app.add_directive('needservice', NeedserviceDirective)
 
     ########################################################################
     # ROLES
@@ -271,9 +277,11 @@ def load_config(app, *args):
 
     # Update NeedDirective to use customized options
     NeedDirective.option_spec.update(extra_options)
+    NeedserviceDirective.option_spec.update(extra_options)
 
     # Update NeedDirective to use customized links
     NeedDirective.option_spec.update(extra_links)
+    NeedserviceDirective.option_spec.update(extra_links)
 
     if title_optional or title_from_content:
         NeedDirective.required_arguments = 0
@@ -305,6 +313,22 @@ def prepare_env(app, env, docname):
         # Used to store all needed information about all filters in document
         env.needs_all_filters = {}
 
+    if not hasattr(env, 'needs_services'):
+        # Used to store all needed information about all services
+        app.needs_services = ServiceManager(app)
+
+    # Register embedded services
+    # env.needs_services.register('jira', JiraService)
+    app.needs_services.register('github-issues', GithubService, gh_type='issue')
+    app.needs_services.register('github-prs', GithubService, gh_type='pr')
+    app.needs_services.register('github-commits', GithubService, gh_type='commit')
+
+    # Register user defined services
+    for name, service in app.config.needs_services.items():
+        if name not in app.needs_services.services.keys():
+            # We found a not yet registered service
+            app.needs_services.register(name, service['class'], **service['class_init'])
+
     needs_functions = NEEDS_FUNCTIONS_CONF
     if needs_functions is None:
         needs_functions = []
